'use strict';

const Model = require('../model');

class Base {

    constructor(conn, options) {
        this.conn = conn;
        this.options = options;
        this.link = null;
        this.model = null;
    }

    define(name, fields, options) {
        let model = new Model(this.conn, name, fields, options);

        this.model = model;

        return model;
    }

    /* -------------------------------------------------------------------------
     * Connections
     * ---------------------------------------------------------------------- */

    getLink() {
        throw new Error('getLink not implemented');
    }

    /* -------------------------------------------------------------------------
     * Find all
     * ---------------------------------------------------------------------- */

    findAll(options) {
        throw new Error('findAll not implemented');
    }

    findAndUpdate(data, options) {
        throw new Error('findAndUpdate not implemented');
    }

    /* -------------------------------------------------------------------------
     * Query
     * ---------------------------------------------------------------------- */

    metadata(options) {
        throw new Error('metadata not implemented');
    }

    explain(query, options) {
        throw new Error('explain not implemented');
    }

    query(query, options) {
        throw new Error('query not implemented');
    }

    /* -------------------------------------------------------------------------
     * Count
     * ---------------------------------------------------------------------- */

    count(options) {
        throw new Error('count not implemented');
    }

    /* -------------------------------------------------------------------------
     * Modify
     * ---------------------------------------------------------------------- */

    insert(data, options) {
        throw new Error('insert not implemented');
    }

    bulkInsert(records, options) {
        throw new Error('bulkInsert not implemented');
    }

    update(data, options) {
        throw new Error('update not implemented');
    }

    destroy(options) {
        throw new Error('destroy not implemented');
    }

    async sync(options) {
    }

    async exists(options) {
        throw new Error('exists not implemented');
    }
}

module.exports = Base;