'use strict';

const _ = require('lodash');

const Model = require('./model');
const types = require('paradox-utils').SchemaTypes;

/**
 * @property {boolean} STRING
 */
class Dblize {

    constructor(options) {
        this.models = {};
        this.config = _.defaultsDeep(options, {
            adapter: null,
            forcePartition: false,
            emptyThrowException: false,
            sync: {
                force: true,
            }
        });
        this.adapter = null;
    }

    /**
     * @returns {Base}
     */
    getAdapter() {
        if(!this.adapter) {
            let Base = require('./adapter/' + this.config.adapter + '.js');
            this.adapter = new Base(this, this.config);
        }

        return this.adapter;
    }

    /**
     * @param name
     * @param fields
     * @param options
     * @returns {Model}
     */
    define(name, fields, options) {
        options = _.defaultsDeep(options, this.config);

        let model = this.getAdapter().define(name, fields, options);

        this.models[name] = model;

        return model;
    }

    /* -------------------------------------------------------------------------
     * Utils
     * ---------------------------------------------------------------------- */

    query(query, options) {
        return this
            .getAdapter()
            .query(query, options)
            .then(result => {
                if(options.model) {
                    // TODO: Hacer un map de result y convertir a instancias
                }

                return result;
            });
    }
}

Dblize.type = types;

for(let key in types) {
    Dblize[key] = types[key];
}

module.exports = Dblize;